NAME
Luv::CLI - command-line dependency manager for love2d projects
VERSION
version 0.001
SYNOPSIS
use Luv::CLI;
Luv::CLI->run;
DESCRIPTION
Top-level App::Cmd application class for luv, a package manager for LÖVE (love2d) game projects. Fetches libraries from git repositories, tracks them in a project manifest, and packages projects into .love files.
NAME
Luv::CLI - command-line dependency manager for love2d projects
AUTHOR
Nobunaga <nobunaga@cpan.org>
LICENSE
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
AUTHOR
Nobunaga <nobunaga@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Ogun.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.